@@ -1,6 +1,6 @@
 import pathlib
 import sys
-from typing import Dict, Literal, Optional, Union
+from typing import Dict, Optional, Union#, Literal
 import warnings
 
 import dill
@@ -61,7 +61,7 @@ ROBUSTNESS_HASHES = {
 
 def get_model_from_robustness(
     arch: str,
-    pretraining: Literal[None, "pytorch", "microsoft"],
+    pretraining: Optional[str], # Literal[None, "pytorch", "microsoft"]
     eps: float = 0.0,
     metric: str = "L2",
     device: Union[torch.device, str] = "cpu",
