@@ -207,14 +207,14 @@ def freeze_model(model):
 def visualize_gradient(t):
     '''
     Visualize gradients of model. To transform gradient to image range [0, 1], we 
-    subtract the mean, divide by 3 standard deviations, and then clip.
+    subtract the mean, divide by 2*3 standard deviations, and then clip.
     
     Args:
         t (tensor): input tensor (usually gradients)
     '''  
     mt = torch.mean(t, dim=[2, 3], keepdim=True).expand_as(t)
     st = torch.std(t, dim=[2, 3], keepdim=True).expand_as(t)
-    return torch.clamp((t - mt) / (3 * st) + 0.5, 0, 1)
+    return torch.clamp((t - mt) / (2*3 * st) + 0.5, 0, 1)
 
 
 def get_accuracy(logits, target):
